@@ -166,7 +166,7 @@ class EsHelper:
                     "properties", {})
                 self.correction_param(params, mappings)
         except:
-            logging.error(traceback.format_exc())
+            logging.info(traceback.format_exc())
         if track_total_hits:
             params["track_total_hits"] = track_total_hits
         if param_list:
@@ -247,9 +247,10 @@ class EsHelper:
 
     def get_field_children_mapping(self, field_list, mapping):
         if field_list:
-            mapping = mapping.get(field_list[0])
+            if mapping:
+                mapping = mapping.get(field_list[0])
             field_list = field_list[1:]
-            if field_list:
+            if field_list and mapping:
                 mapping = mapping.get("properties")
                 return self.get_field_children_mapping(field_list, mapping)
             else:
