@@ -5,7 +5,7 @@ import warnings
 class SMX:
     @staticmethod
     def generate_sm2_key():
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             smx_sm2 = importlib.import_module("pysmx.SM2")
         except ImportError as e:
@@ -15,7 +15,7 @@ class SMX:
 
     @staticmethod
     def generate_sm2_sign(string: str, DA, k, len_para, Hexstr=0, encoding="utf-8"):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             smx_sm2 = importlib.import_module("pysmx.SM2")
         except ImportError as e:
@@ -24,7 +24,7 @@ class SMX:
 
     @staticmethod
     def verify_sm2_sign(sign, string: str, PA, len_para, Hexstr=0, encoding="utf-8"):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             smx_sm2 = importlib.import_module("pysmx.SM2")
         except ImportError as e:
@@ -33,7 +33,7 @@ class SMX:
 
     @staticmethod
     def encrypt(string: str, **kwargs):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             smx_sm2 = importlib.import_module("pysmx.SM2")
             smx_sm3 = importlib.import_module("pysmx.SM3")
@@ -64,7 +64,7 @@ class SMX:
 
     @staticmethod
     def decrypt(string: str, **kwargs):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             smx_sm2 = importlib.import_module("pysmx.SM2")
             smx_sm4 = importlib.import_module("pysmx.SM4")
