@@ -21,6 +21,7 @@ from tornado.web import RequestHandler, Application
 
 from lesscode.task.task_helper import TaskHelper
 from lesscode.utils.es_log.record_log import es_record_log
+from lesscode.utils.json import JSONEncoder
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.response_result import ResponseResult
 from lesscode.web.router_mapping import RouterMapping
@@ -260,19 +261,28 @@ class BaseHandler(RequestHandler):
             重写父类方法
         :return:
         """
-        origin = self.request.headers.get("Origin")
-        if origin:
-            self.set_header("Access-Control-Allow-Origin", origin)
+        if not options.cors:
+            origin = self.request.headers.get("Origin")
+            if origin:
+                self.set_header("Access-Control-Allow-Origin", origin)
+            else:
+                self.set_header("Access-Control-Allow-Origin", "*")
+            self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
+            self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
+            self.set_header("Access-Control-Allow-Headers",
+                            "x-requested-with,Authorization,Can-read-cache,Content-Type,User")
+            self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
+            self.set_header("Access-Control-Expose-Headers", "Access-Token")
+            self.set_header("Access-Control-Allow-Credentials", "true")
+            self.set_header("Content-Type", "application/json; charset=UTF-8")
         else:
-            self.set_header("Access-Control-Allow-Origin", "*")
-        self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
-        self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
-        self.set_header("Access-Control-Allow-Headers",
-                        "x-requested-with,Authorization,Can-read-cache,Content-Type,User")
-        self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
-        self.set_header("Access-Control-Expose-Headers", "Access-Token")
-        self.set_header("Access-Control-Allow-Credentials", "true")
-        self.set_header("Content-Type", "application/json; charset=UTF-8")
+            origin = self.request.headers.get("Origin")
+            if origin:
+                self.set_header("Access-Control-Allow-Origin", origin)
+            else:
+                self.set_header("Access-Control-Allow-Origin", "*")
+            for key, value in options.cors.items():
+                self.set_header(key, value)
 
     def data_received(self, chunk: bytes) -> Optional[Awaitable[None]]:
         """
@@ -311,7 +321,7 @@ class BaseHandler(RequestHandler):
         """
         return "%s %s %s %s %s" % (
             self.request.method, self.request.path, self.request.arguments, self.request.remote_ip,
-            self.request.headers["User-Agent"])
+            self.request.headers.get("User-Agent") or self.request.headers.get("user-agent"))
 
     def get_current_user(self) -> Any:
         """
@@ -367,22 +377,6 @@ class BaseHandler(RequestHandler):
         data["modify_time"] = datetime.now()
 
 
-class JSONEncoder(json.JSONEncoder):
-    def default(self, o):
-        object_class_name = o.__class__.__name__
-        if object_class_name == "ObjectId":
-            return str(o)
-        elif object_class_name == "datetime":
-            return str(o)
-        elif object_class_name == "bytes":
-            return str(o, encoding="utf-8")
-        elif object_class_name == "set":
-            return list(o)
-        elif object_class_name == "Decimal":
-            return str(o)
-        return json.JSONEncoder.default(self, o)
-
-
 class User:
     """
     用户对象类
